;;File: debian-ispell.el
;;Description: Emacsen support for Debian package dictionaries-common
;;Author: Rafael Laboissire <rafael@debian.org>
;;Created on: Tue Oct 26 10:16:12 CEST 1999
;;Last modified on: Wed Nov  3 14:15:37 CET 1999

(defconst debian-ispell-xemacs-p
  (string-match "XEmacs\\|Lucid" emacs-version))

(if (not debian-ispell-xemacs-p)
;; The following function was stolen from the XEmacs 20.4
;; distribution.  It is here to provide compatibility with Emacs20.
    (defun symlink-expand-file-name (filename)
      "If FILENAME is a symlink, return its non-symlink equivalent.
Unlike `file-truename', this doesn't chase symlinks in directory
components of the file or expand a relative pathname into an
absolute one."
      (let ((count 20))
	(while (and (> count 0) (file-symlink-p filename))
	  (setq filename (file-symlink-p filename)
		count (1- count)))
	(if (> count 0)
	    filename
	  (error "Apparently circular symlink path")))))

(defvar debian-ispell-dictionary-alist 
  '((nil "[A-Za-z]" "[^A-Za-z]" "[']" nil ("-B") nil iso-8859-1))
  "Alist of dictionaries used internally by the Debian ispell
initialization scheme.  Its value will be used to set
`ispell-dictionary-alist' after ispell.el is loaded.

Do not change this variable directly.  Use the
`debian-ispell-add-dictionary-entry' function instead.")

(defvar debian-ispell-dictionary 
  "default"
  "The name of the dictionary that will become the default after
loading of ispell.el.")

(defconst debian-ispell-default-symlink
  (let* ((default-symlink "/usr/lib/ispell/default.hash")
	 (default-hash (if (file-symlink-p default-symlink)
			   (symlink-expand-file-name default-symlink)
			 nil)))
    (if default-hash
	(substring default-hash 0
		   (string-match "\\.hash$" default-hash))
      nil))
  "This constant is for internal use of the ispell Debian initialization
procedure.  It contains the name of the file the symlink
/usr/lib/ispell/default.hash points to (stripped from the initial
path and the trailing \".hash\"")

(defun debian-ispell-add-dictionary-entry (entry &optional name)
  "Adds an ENTRY to the ispell-dictionary-alist variable. See the 
documentation of the variable ispell-dictionary-alist for the format 
of ENTRY.  

Also sets the default ispell-dictionary if NAME corresponds to the system 
default (as in /usr/lib/ispell/default.hash).  If NAME is nil, (car ENTRY)
is used instead."
  (set-variable 'debian-ispell-dictionary-alist
		(append (list entry) debian-ispell-dictionary-alist))
  (if (not name)
      (setq name (car entry)))
  (if debian-ispell-default-symlink
      (if (equal debian-ispell-default-symlink name)
	  (set-variable 'debian-ispell-dictionary (car entry)))))

;; Hook on ispell.el
(defun debian-ispell-set-vars ()
  (set-variable 'ispell-dictionary debian-ispell-dictionary)
  (set-variable 'ispell-dictionary-alist
		debian-ispell-dictionary-alist)
  (set-variable 'flyspell-default-dictionary debian-ispell-dictionary))

(add-hook 'ispell-load-hook 'debian-ispell-set-vars)

;; Make sure the patched ispell.el is first in the loadpath

(setq load-path
      (append (list (concat "/usr/share/" 
			    (symbol-name debian-emacs-flavor) 
			    "/site-lisp/dictionaries-common"))
	       load-path))


;Local Variables:
;mode: lisp
;End:
